@@ -1,6 +1,7 @@
 /*
  *   SPDX-FileCopyrightText: 2011 Matthias Fuchs <mat69@gmx.net>
  *   SPDX-FileCopyrightText: 2015 Marco Martin <mart@kde.org>
+ *   SPDX-FileCopyrightText: 2022 Alexander Lohnau <alexander.lohnau@gmx.de>
  *
  *   SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -15,7 +16,7 @@
 #include <QImage>
 
 ComicArchiveJob::ComicArchiveJob(const QUrl &dest,
-                                 Plasma::DataEngine *engine,
+                                 ComicEngine *engine,
                                  ComicArchiveJob::ArchiveType archiveType,
                                  IdentifierType identifierType,
                                  const QString &pluginName,
@@ -45,6 +46,7 @@ ComicArchiveJob::ComicArchiveJob(const QUrl &dest,
     } else {
         qWarning() << "Could not create a temporary file for the zip file.";
     }
+    connect(engine, &ComicEngine::requestFinished, this, &ComicArchiveJob::dataUpdated);
 }
 
 ComicArchiveJob::~ComicArchiveJob()
@@ -121,8 +123,9 @@ void ComicArchiveJob::start()
     }
 }
 
-void ComicArchiveJob::dataUpdated(const QString &source, const Plasma::DataEngine::Data &data)
+void ComicArchiveJob::dataUpdated(const ComicMetaData &data)
 {
+    const QString source = data.identifier;
     if (!mZip) {
         qWarning() << "No zip file, aborting.";
         setErrorText(i18n("No zip file is existing, aborting."));
@@ -131,21 +134,21 @@ void ComicArchiveJob::dataUpdated(const QString &source, const Plasma::DataEngin
         return;
     }
 
-    const QString currentIdentifier = data[QStringLiteral("Identifier")].toString();
+    const QString currentIdentifier = data.identifier;
     QString currentIdentifierSuffix = currentIdentifier;
     currentIdentifierSuffix.remove(mPluginName + QLatin1Char(':'));
 
-    const QImage image = data[QStringLiteral("Image")].value<QImage>();
-    const bool hasError = data[QStringLiteral("Error")].toBool() || image.isNull();
-    const QString previousIdentifierSuffix = data[QStringLiteral("Previous identifier suffix")].toString();
-    const QString nextIdentifierSuffix = data[QStringLiteral("Next identifier suffix")].toString();
-    const QString firstIdentifierSuffix = data[QStringLiteral("First strip identifier suffix")].toString();
+    const QImage image = data.image;
+    const bool hasError = data.error || image.isNull();
+    const QString previousIdentifierSuffix = data.previousIdentifier;
+    const QString nextIdentifierSuffix = data.nextIdentifier;
+    const QString firstIdentifierSuffix = data.firstStripIdentifier;
 
-    mAuthors << data[QStringLiteral("Comic Author")].toString().split(QLatin1Char(','), Qt::SkipEmptyParts);
+    mAuthors << data.comicAuthor.split(QLatin1Char(','), Qt::SkipEmptyParts);
     mAuthors.removeDuplicates();
 
     if (mComicTitle.isEmpty()) {
-        mComicTitle = data[QStringLiteral("Title")].toString();
+        mComicTitle = data.stripTitle;
     }
 
     if (hasError) {
@@ -227,8 +230,6 @@ void ComicArchiveJob::dataUpdated(const QString &source, const Plasma::DataEngin
         setError(KilledJobError);
         emitResultIfNeeded();
     }
-
-    mEngine->disconnectSource(source, this);
 }
 
 bool ComicArchiveJob::doKill()
@@ -263,14 +264,14 @@ void ComicArchiveJob::defineTotalNumber(const QString &currentSuffix)
     // calculate a new value for total files, can be different from the previous one,
     // if there are no strips for certain days/numbers
     if (!currentSuffix.isEmpty()) {
-        if (mIdentifierType == Date) {
+        if (mIdentifierType == IdentifierType::DateIdentifier) {
             const QDate current = QDate::fromString(currentSuffix, QStringLiteral("yyyy-MM-dd"));
             const QDate to = QDate::fromString(mToIdentifierSuffix, QStringLiteral("yyyy-MM-dd"));
             if (current.isValid() && to.isValid()) {
                 // processed files + files still to download
                 mTotalFiles = mProcessedFiles + qAbs(current.daysTo(to));
             }
-        } else if (mIdentifierType == Number) {
+        } else if (mIdentifierType == IdentifierType::NumberIdentifier) {
             bool result = true;
             bool ok;
             const int current = currentSuffix.toInt(&ok);
@@ -295,13 +296,13 @@ void ComicArchiveJob::findTotalNumberFromTo()
         return;
     }
 
-    if (mIdentifierType == Date) {
+    if (mIdentifierType == IdentifierType::DateIdentifier) {
         const QDate from = QDate::fromString(mFromIdentifierSuffix, QStringLiteral("yyyy-MM-dd"));
         const QDate to = QDate::fromString(mToIdentifierSuffix, QStringLiteral("yyyy-MM-dd"));
         if (from.isValid() && to.isValid()) {
             mTotalFiles = qAbs(from.daysTo(to)) + 1;
         }
-    } else if (mIdentifierType == Number) {
+    } else if (mIdentifierType == IdentifierType::NumberIdentifier) {
         bool result = true;
         bool ok;
         const int from = mFromIdentifierSuffix.toInt(&ok);
@@ -332,8 +333,7 @@ void ComicArchiveJob::requestComic(QString identifier) // krazy:exclude=passbyva
                        qMakePair(QStringLiteral("source"), identifier),
                        qMakePair(QStringLiteral("destination"), mDest.toString()));
 
-    mEngine->connectSource(identifier, this);
-    //    mEngine->query( identifier );
+    mEngine->requestSource(identifier);
 }
 
 bool ComicArchiveJob::addFileToZip(const QString &path)
