@@ -13,7 +13,9 @@
 
 class KDirWatch;
 
-class KateSessions : public Plasma::AbstractRunner
+using namespace Plasma;
+
+class KateSessions : public AbstractRunner
 {
     Q_OBJECT
 
@@ -21,16 +23,14 @@ public:
     explicit KateSessions(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
     ~KateSessions() override;
 
-    void match(Plasma::RunnerContext &context) override;
-    void run(const Plasma::RunnerContext &context, const Plasma::QueryMatch &match) override;
+    void match(RunnerContext &context) override;
+    void run(const RunnerContext &context, const QueryMatch &match) override;
 
 private Q_SLOTS:
-    void loadSessions();
+    QStringList loadSessions();
 
 private:
-    KDirWatch *m_sessionWatch = nullptr;
     QString m_sessionsFolderPath;
-    QStringList m_sessions;
     const QLatin1String m_triggerWord = QLatin1String("kate");
 };
 
